@@ -33,7 +33,13 @@ LAUNCH_TYPE_T = "EcsLaunchType"
 LAUNCH_TYPE = Parameter(
     LAUNCH_TYPE_T,
     Type="String",
-    AllowedValues=["EC2", "FARGATE", "FARGATE_PROVIDERS", "CAPACITY_PROVIDERS"],
+    AllowedValues=[
+        "EC2",
+        "FARGATE",
+        "FARGATE_PROVIDERS",
+        "CLUSTER_MODE",
+        "SERVICE_MODE",
+    ],
     Default="FARGATE",
 )
 
