@@ -70,6 +70,7 @@ SUPPORTED_X_MODULE_NAMES = [
     "alarms",
     "codeguru_profiler",
     "ssm_parameter",
+    "opensearch",
 ]
 
 SUPPORTED_X_MODULES = [f"{X_KEY}{mod_name}" for mod_name in SUPPORTED_X_MODULE_NAMES]
@@ -83,7 +84,7 @@ EXCLUDED_X_KEYS = [
     f"{X_KEY}cluster",
     f"{X_KEY}dashboards",
 ]
-TCP_MODES = ["rds", "appmesh", "elbv2", "docdb", "elasticache", "efs"]
+TCP_MODES = ["rds", "appmesh", "elbv2", "docdb", "elasticache", "efs", "opensearch"]
 TCP_SERVICES = [f"{X_KEY}{mode}" for mode in TCP_MODES]
 
 
