@@ -17,7 +17,8 @@ from ecs_composex.common.compose_resources import get_parameter_settings
 from ecs_composex.common.services_helpers import extend_container_envvars
 from ecs_composex.common.stacks import ComposeXStack
 from ecs_composex.ecs.ecs_iam import define_service_containers
-from ecs_composex.kms.kms_perms import ACCESS_TYPES as KMS_ACCESS_TYPES
+from ecs_composex.iam.import_sam_policies import get_access_types
+from ecs_composex.kms.kms_params import MOD_KEY as KMS_MOD
 
 
 def determine_arns(arn, policy_doc, ignore_missing_primary=False):
@@ -89,6 +90,33 @@ def generate_resource_permissions(
     return resource_policies
 
 
+def generate_resource_permissions_statements(
+    resource_name, policies, arn, ignore_missing_primary=False
+):
+    """
+    Function to generate IAM permissions for a given x-resource. Returns the mapping of these for the given resource.
+    Suffix takes the values and reduces to the first 118 characters to ensure policy length is below 128
+    Short prefix ensures the uniqueness of the policy name but allows to be a constant throughout the life
+    of the CFN Stack. It is 8 chars long, leaving a 2 chars margin
+
+    :param str resource_name: The name of the resource
+    :param dict policies: the policies associated with the x-resource type.
+    :param str,AWSHelper arn: The ARN of the resource if already looked up.
+    :param bool ignore_missing_primary: Whether the policy should contain ${ARN} at least
+    :return: dict of the IAM policies associated with the resource.
+    :rtype dict:
+    """
+    resource_policies = {}
+    for a_type in policies:
+        LOG.debug(a_type)
+        policy_doc = policies[a_type].copy()
+        resources = determine_arns(arn, policy_doc, ignore_missing_primary)
+        policy_doc["Sid"] = f"{a_type}To{resource_name}"
+        policy_doc["Resource"] = resources
+        resource_policies[a_type] = policy_doc
+    return resource_policies
+
+
 def add_iam_policy_to_service_task_role(family, resource, perms, access_type, services):
     """
     Function to expand the ECS Task Role policy with the permissions for the resource
@@ -191,7 +219,7 @@ def handle_kms_access(mapping_family, resource, target, selected_services):
         mapping_family, resource.logical_name, resource.kms_arn_attr.title
     )
     kms_perms = generate_resource_permissions(
-        f"{resource.logical_name}KmsKey", KMS_ACCESS_TYPES, arn=key_arn
+        f"{resource.logical_name}KmsKey", get_access_types(KMS_MOD), arn=key_arn
     )
     add_iam_policy_to_service_task_role(
         target[0].template,
